# The basics

This section covers the basic steps of working with astronomical data using Eloy. These tutorials show you the main tasks you'll need for most data processing, from loading your data to measuring star brightness.

```{toctree}
:maxdepth: 1

datasets
calibration
stacking
video
plate-solving
photometry
```
